import type { PaginatedListRequest } from '../types/PaginatedListRequest.js';
import { AbstractDataSource } from './AbstractDataSource.svelte.js';
/**
 * Uses the {@link https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API Fetch API} to request the data from an api endpoint via HTTP POST requests
 */
export declare class FetchApiDataSource<Data> extends AbstractDataSource<Data> {
    private url;
    private options;
    /**
     * Create a new data source to fetch your paginated table data from an api endpoint.
     *
     * The endpoint will receive HTTP POST requests with a json body consisting of an {@link PaginatedListRequest}.
     * Your server has to answer with a {@link PaginatedListResponse} json body.
     * @param url a url to your api endpoint, for example `/api/users/list`
     * @param options an object with [request init options](https://developer.mozilla.org/en-US/docs/Web/API/fetch#options) which get passed directly to fetch
     */
    constructor(url: string, options?: RequestInit);
    requestData(data: PaginatedListRequest<Data>): void;
}
