import type { ParsedSearchQuery } from '../searchParser/index.js';
import type { PaginatedListRequest } from '../types/PaginatedListRequest.js';
import { AbstractDataSource } from './AbstractDataSource.svelte.js';
export interface LocalDataSourceOptions<Data> {
    filtering?: {
        textSearchColumns?: (keyof Data)[];
        filterFunction?: (item: Data, searchQuery: ParsedSearchQuery) => boolean;
    };
}
/**
 * The local data source requires the data to be passed in as an array.
 * The dataTable is still paginated, sorted and searchable by performing everything on the clientside
 */
export declare class LocalDataSource<Data> extends AbstractDataSource<Data> {
    private data;
    private options;
    /**
     * Create a new local data source to use the passed in array as data.
     *
     * @param data array with all table entries
     * @param options
     */
    constructor(data: Data[], options?: LocalDataSourceOptions<Data>);
    requestData(data: PaginatedListRequest<Data>): void;
    private filterData;
    private sortData;
}
