import type { IDataSource } from '../IDataSource.js';
import { QueryResult } from '../QueryResult.js';
import type { ApiFunction } from '../../types/ApiFunction.js';
import type { FullDataTableConfig } from '../../types/DataTableConfig.js';
import type { PaginatedListRequest } from '../../types/PaginatedListRequest.js';
import type { PaginatedListResponse } from '../../types/PaginatedListResponse.js';
import type { CreateQueryOptions, CreateQueryResult } from '@tanstack/svelte-query';
export type DataTableUseQueryStoreResult<Data> = CreateQueryResult<PaginatedListResponse<Data>, Error>;
export type DataTableUseQueryOptions<Data> = CreateQueryOptions<PaginatedListResponse<Data>, Error, PaginatedListResponse<Data>, DataTableQueryKey<Data>>;
type AdditionalUseQueryOptions<Data> = Partial<Omit<DataTableUseQueryOptions<Data>, 'queryKey' | 'queryFn'>>;
export type DataTableQueryKey<Data> = [key: string, request: PaginatedListRequest<Data>];
/**
 * Uses the Svelte Query library to fetch your paginated table data.
 */
export declare class SvelteQueryDataSource<Data> implements IDataSource<Data> {
    apiFunction: ApiFunction<Data> | undefined;
    additionalQueryOptions: AdditionalUseQueryOptions<Data>;
    protected dataTableConfig: FullDataTableConfig<Data> | undefined;
    private queryKey;
    private queryOptions;
    private dataQuery;
    private initialized;
    private queryKeyPrefix;
    private queryEnabled;
    /**
     * Create a new data source to fetch your paginated table data from an api endpoint
     * using Svelte Query in the background to manage requests, caching and more.
     *
     * @param apiFunction the api function which actually fetches your data, passed through to Svelte Query as the [query function](https://sveltequery.vercel.app/guides/query-functions).
     * A query function can be literally any function that returns a promise. The promise that is returned should either resolve the data or throw an error.
     * @param additionalQueryOptions additional options passed to Svelte Query
     *
     * @see {@link https://sveltequery.vercel.app/reference/useQuery}
     */
    constructor(apiFunction: ApiFunction<Data>, additionalQueryOptions?: AdditionalUseQueryOptions<Data>);
    private _queryResult;
    get queryResult(): QueryResult<Data>;
    setConfig(config: FullDataTableConfig<Data>): void;
    requestData(data: PaginatedListRequest<Data>): void;
    private createQueryOptions;
    private deriveQueryResult;
    private wrapApiFunction;
    private normalizeRequestData;
}
export {};
