import { readable } from 'svelte/store';
export const browser = typeof window !== 'undefined';
export function hasOwnProperty(obj, prop) {
    // eslint-disable-next-line @typescript-eslint/ban-types
    return typeof obj !== 'undefined' && obj !== null && Object.hasOwn(obj, prop);
}
export function isIndexable(obj) {
    return typeof obj !== 'undefined' && obj !== null;
}
export function isDateTime(obj) {
    return !!(obj && hasOwnProperty(obj, 'isLuxonDateTime') && obj.isLuxonDateTime);
}
export function isStore(store) {
    return !!store && hasOwnProperty(store, 'subscribe');
}
export function wrapPossibleStore(store) {
    return isStore(store) ? store : readable(store);
}
export function clamp(value, min, max) {
    return Math.min(Math.max(value, min), max);
}
export function debounce(func, waitTime) {
    let timer;
    return (...args) => {
        clearTimeout(timer);
        timer = setTimeout(() => func(...args), waitTime);
    };
}
export function preventEvent(e) {
    e.preventDefault();
}
const missingKeyValueMappings = new Set();
/**
 * Map key-value pairs using the passed in map.
 *
 * @param map the mapping from key to value
 * @param key the key to get the value for
 * @param defaultToKey should the key be returned as the value, in case a key to value mapping doesn't exist
 */
export function mapValue(map, key, defaultToKey = false) {
    if (hasOwnProperty(map, key)) {
        return map[key];
    }
    else {
        if (defaultToKey) {
            return key;
        }
        else {
            if (!missingKeyValueMappings.has(key)) {
                const keys = Object.keys(map).slice(0, 5).join(', ');
                const values = Object.values(map).slice(0, 5).join(', ');
                console.warn(`Can't map key ${key} to a value for the mapping ${keys} -> ${values}`);
                missingKeyValueMappings.add(key);
            }
            return undefined;
        }
    }
}
export function wrapFetchToThrow(func) {
    return async (request) => {
        const res = await func(request);
        let resData = undefined;
        try {
            resData = await res.json();
            // eslint-disable-next-line no-empty
        }
        catch (err) {
            console.error(err);
        }
        if (res.ok && typeof resData !== 'undefined') {
            return resData;
        }
        else {
            const errorMessage = hasOwnProperty(resData, 'message') ? String(resData.message) : 'Unknown network error';
            const error = new Error(errorMessage);
            if (resData) {
                Object.assign(error, resData);
            }
            throw error;
        }
    };
}
