import { fromStore } from 'svelte/store';
export function createMessageFormatter(dataTableConfig) {
    if (dataTableConfig.messageFormatter === 'config') {
        return createConfigMessageFormatter(dataTableConfig, dataTableConfig.messageConfig);
    }
    else if (typeof dataTableConfig.messageFormatter === 'object') {
        return createSvelteI18nMessageFormatter(dataTableConfig, dataTableConfig.messageFormatter);
    }
    else {
        throw new Error(`Invalid message formatter ${dataTableConfig.messageFormatter} in dataTable ${dataTableConfig.type}`);
    }
}
function createConfigMessageFormatter(dataTableConfig, messageConfig) {
    const missingMessageIds = new Set();
    return (messageId, options = {}) => {
        const prefix = `dataTable.${dataTableConfig.type}.`;
        if (messageId.startsWith(prefix)) {
            messageId = messageId.substring(prefix.length);
        }
        const rawMessage = indexObject(messageConfig, messageId);
        if (!rawMessage) {
            if (options.default) {
                return options.default;
            }
            if (!missingMessageIds.has(messageId)) {
                console.warn(`DataTable ${dataTableConfig.type} is missing message ${messageId}`);
                missingMessageIds.add(messageId);
            }
            return messageId;
        }
        return replaceMessageVariables(rawMessage, options.values ?? {});
    };
}
function indexObject(object, deepKey) {
    return deepKey.split('.').reduce(
    // @ts-ignore
    (deepObject, key) => {
        if (typeof deepObject === 'undefined' ||
            deepObject === null ||
            typeof deepObject[key] === 'undefined' ||
            deepObject[key] === null) {
            return undefined;
        }
        return deepObject[key];
    }, object);
}
function replaceMessageVariables(message, values) {
    return message.replace(/{(\w+)}/g, (_, key) => String(values[key]));
}
function createSvelteI18nMessageFormatter(dataTableConfig, format) {
    const svelteI18nFormat = fromStore(format);
    return (messageId, options) => {
        return svelteI18nFormat.current({
            id: `${dataTableConfig.messageFormatterPrefix ?? ''}${messageId}`,
            values: options?.values,
            default: options?.default
        });
    };
}
